@@ -3,14 +3,8 @@ package NeedsOpenSSL;
 use strict;
 use warnings;
 
-use parent 'Test::Class';
-
 use Test::More;
 
-use File::Which ();
-
-use OpenSSL_Control ();
-
 sub SKIP_CLASS {
     my ($self) = @_;
 
@@ -23,12 +17,12 @@ sub _get_openssl {
     my ($self) = @_;
 
     return $self->{'_ossl_bin'} ||= do {
-        my $bin = OpenSSL_Control::openssl_bin();
+        my $bin = `which openssl`;
+        die if $?;
+        chomp $bin;
 
-        if ($bin) {
-            note "Using OpenSSL binary: $bin";
-            note OpenSSL_Control::run(qw(version -a));
-        }
+        note "Using OpenSSL binary: $bin";
+        note `$bin version -a`;
 
         $bin;
     };
